/**
 * \file server/fw_util_ipf.h
 *
 * \brief Header file for fw_util_ipf.c.
 */

/*  Fwknop is developed primarily by the people listed in the file 'AUTHORS'.
 *  Copyright (C) 2009-2015 fwknop developers and contributors. For a full
 *  list of contributors, see the file 'CREDITS'.
 *
 *  License (GNU General Public License):
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *****************************************************************************
*/
#ifndef FW_UTIL_IPF_H
#define FW_UTIL_IPF_H

/* ipfw command args   (gotta flesh these out)         
*/
#define IPF_ADD_RULE_ARGS ""
#define IPF_ADD_OUT_RULE_ARGS ""
#define IPF_ADD_FWD_RULE_ARGS ""
#define IPF_ADD_DNAT_RULE_ARGS ""
#define IPF_ADD_SNAT_RULE_ARGS ""
#define IPF_DEL_RULE_ARGS ""
#define IPF_LIST_RULES_ARGS ""
#define IPF_ANY_IP ""

#endif /* FW_UTIL_IPF_H */

/***EOF***/
